@@ -12,6 +12,7 @@
 #include <QDateTime>
 #include <QDebug>
 #include <QFile>
+#include <QPointer>
 #include <QTimer>
 
 // STL
@@ -466,7 +467,8 @@ public:
             // Check whether we got an item representing a non-existent file,
             // if so, schedule its removal from the database
             // we want to do this async so that we don't block
-            std::thread([=, this] {
+            QPointer model{d->q};
+            std::thread([model, newItems] {
                 QList<QString> missingResources;
                 for (const auto &item : newItems) {
                     // QFile.exists() can be incredibly slow (eg. if resource is on remote filesystem)
@@ -479,8 +481,10 @@ public:
                     return;
                 }
 
-                QTimer::singleShot(0, this->d->q, [=, this] {
-                    d->q->forgetResources(missingResources);
+                QTimer::singleShot(0, model, [missingResources, model] {
+                    if (model) {
+                        model->forgetResources(missingResources);
+                    }
                 });
             }).detach();
         }
